# WeaviateQueryResultVectorValue


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from _generated.models.weaviate_query_result_vector_value import WeaviateQueryResultVectorValue

# TODO update the JSON string below
json = "{}"
# create an instance of WeaviateQueryResultVectorValue from a JSON string
weaviate_query_result_vector_value_instance = WeaviateQueryResultVectorValue.from_json(json)
# print the JSON string representation of the object
print(WeaviateQueryResultVectorValue.to_json())

# convert the object into a dict
weaviate_query_result_vector_value_dict = weaviate_query_result_vector_value_instance.to_dict()
# create an instance of WeaviateQueryResultVectorValue from a dict
weaviate_query_result_vector_value_from_dict = WeaviateQueryResultVectorValue.from_dict(weaviate_query_result_vector_value_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


